# The SAM (Subcortical Atlas of the Marmoset) template and atlas

In depth information on the SAM v1.0 can be read in our paper:

    #Include citation information here

For any issues or questions, contact Kadharbatcha Saleem at
    saleemks @ mail.nih.gov
    glend @ mail.nih.gov

## Description
A comprehensive three-dimensional digital atlas of subcortical regions based 
on MRI and histology has a broad array of applications for anatomical, 
functional, and clinical studies.

## Citation
Kadharbatcha S Saleem, Alexandru V Avram, Daniel Glen, Vincent Schram, and Peter J Basser
The Subcortical Atlas of the Marmoset (“SAM”) monkey based on high-resolution 
MRI and matched histology with multiple stains


## Atlases
The SAM atlas for the marmoset is provided here, version 1.0, including 
subcortical, brainstem and cerebellar regions

## Download

The `@Install_SAM_Marmoset` command is provided in AFNI to allow for downloading
of the SAM atlas and template with a single command.

## SAM v1 Files
After downloading the SAM v1 files and extracting its contents, you will see
the following directory SAM_Marmoset_subcortical_dist::

- **SAMv1.0.nii.gz**                     : SAMv1.0 symmetric subcortical atlas
- **SAM_T2_template.nii.gz**             : SAMv1.0 symmetric T2 template
- **SAM_MTR_template.nii.gz**            : SAMv1.0 symmetric MTR template
- **SAM_PA_template.nii.gz**             : SAMv1.0 symmetric PA template
- **SAM_DEC_RGB_template.nii.gz**        : SAMv1.0 symmetric DEC RGB template
- **CustomAtlases.niml**                 : Atlas definitions for AFNI
- **SessionAtlases.niml**                : Local atlas definitions for AFNI
- **readme.md**                          : This file
- **SAM_labels.txt**                     : Simplified region labels in text format
- **Table_1_ALL_Subcortical_areas.xlsx** : region labels in Excel format
- **surfs**                              : directory of isosurfaces for each region

## AFNI
While the SAM atlas works with any neuroimaging platform that accepts
NIFTI/GIFTI format, the SAM template and atlas have been designed
to integrate especially well into AFNI (Cox, 1996). For AFNI installation
not done with the @Install scripts, set the following AFNI environment variables
in the .afnirc configuration file, with the `@AfniEnv -set` command or as an
variable within the shell environment.
```
AFNI_ATLAS_COLORS = SAMv1.0
AFNI_WHEREAMI_DEC_PLACES = 3
AFNI_TEMPLATE_SPACE_LIST = SAM_Marmoset
```

## MRI Alignment
The SAM template and atlas can be used for group analysis for marmosets.
AFNI includes @animal_warper that allows for aligning animal (and
specifically nonhuman primate) data to the SAM template. Affine and
nonlinear alignments can be calculated with a single command, and it
additionally provides QC metrics and images that allow you to easily
evaluate the accuracy of your alignment. Additionally, @animal_warper
can take atlases and the segmentation from the SAM template space and
warp them to the native space, allowing for ROI-based analyses in native
space. The following is an example command using the SAM atlas with
@animal_warper:

```bash
@animal_warper                                                  \
    -input  anat-sub-000.nii.gz                                 \
    -base   SAM_Marmoset_dist/SAM_T2_template.nii.gz            \
    -atlas  SAMv1.0.nii.gz                                      \
    -feature_size 0.8                                           \
    -outdir AW_out_sub-000/                                     \
    -ok_to_exist
```

Example alignment scripts for data from the Riken Institute and for the
MBMv3 template are provided here:

link here

Warp files generated from @animal_warper can be directly used for fMRI
analysis in SAM template space. AFNI's processing pipeline generation
program (`afni_proc.py`) will take these warps and combine them with
volume registration to prevent repeated interpolation of fMRI data.

## IsoSurface visualization
Using the suma program in AFNI, load region surfaces with the template
with this command:

```bash
suma -vol SAM_T2_template.nii.gz -onestate -i surfs/*.gii
```


### References

